Colr

Struct Colr 

pub struct Colr<'a> { /* private fields */ }
Implementations

Source

impl<'a> Colr<'a>

pub fn new(data: &'a [u8]) -> Self

Creates a new color table from a byte slice containing the table data.

pub fn version(&self) -> u16

Returns the version of the table.

pub fn num_glyphs(&self) -> u16

Returns the number of glyphs in the table.

pub fn glyph(&self, index: u16) -> Option<Glyph<'a>>

Returns the glyph at the specified index.

pub fn find_glyph(&self, gid: GlyphId) -> Option<Glyph<'a>>

Returns the glyph for the specified identifier.

pub fn glyphs(&self) -> impl Iterator<Item = Glyph<'a>> + 'a + Clone

Returns an iterator over the glyphs in the table.

pub fn num_base_paints(&self) -> u32

Returns the number of base paints.

pub fn base_paint(&self, index: u32) -> Option<(GlyphId, Paint<'a>)>

Returns the glyph identifier and base paint at the specified index.

pub fn find_base_paint(&self, gid: GlyphId) -> Option<Paint<'a>>

Returns the base paint for the specified glyph identifier.

pub fn base_paints( &self, ) -> impl Iterator<Item = (GlyphId, Paint<'a>)> + 'a + Clone

Returns an iterator over the collection of base paints in the table.

pub fn num_paint_layers(&self) -> u32

Returns the number of paint layers in the table.

pub fn paint_layer(&self, index: u32) -> Option<Paint<'a>>

Returns the paint layer at the specified index.

pub fn paint_layers(&self) -> impl Iterator<Item = Paint<'a>> + 'a + Clone

Returns an iterator over the paint layers in the table.

pub fn num_clip_boxes(&self) -> u32

Returns the number of clip boxes in the table.

pub fn clip_box(&self, index: u32) -> Option<(Range<GlyphId>, ClipBox)>

Returns the glyph identifier range and clip box for the specified index.

pub fn find_clip_box(&self, gid: GlyphId) -> Option<ClipBox>

Returns the clip box for the specified glyph identifier.

pub fn clip_boxes( &self, ) -> impl Iterator<Item = (Range<GlyphId>, ClipBox)> + 'a + Clone

Returns an iterator over the clip boxes in the table.

pub fn var_mapping(&self) -> Option<DeltaSetIndexMap<'a>>

Returns the mapping for variation indices.

pub fn ivs(&self) -> Option<ItemVariationStore<'a>>

Returns the item variation store.