ScriptRecord

Struct ScriptRecord 

pub struct ScriptRecord {
    pub tag: Tag,
    pub offset: u32,
    pub num_languages: u16,
}
Information about a script.

Fields

tag: Tag

Tag that identifies the script.

offset: u32

Offset to the script table from the beginning of the associated layout table.

num_languages: u16

Number of languages associated with the script.

Implementations

Source

impl ScriptRecord

pub fn materialize<'a>(&self, layout: &'a Layout<'a>) -> Script<'a>

Creates a new bound script for the specified layout context. The script must belong to the associated layout table.