pub struct ScriptRecord {
pub tag: Tag,
pub offset: u32,
pub num_languages: u16,
}Expand description
Information about a script.
Fields
tag: TagTag that identifies the script.
offset: u32Offset to the script table from the beginning of the associated layout table.
num_languages: u16Number of languages associated with the script.
Implementations
Sourceimpl ScriptRecord
impl ScriptRecord
Sourcepub fn materialize<'a>(&self, layout: &'a Layout<'a>) -> Script<'a>
pub fn materialize<'a>(&self, layout: &'a Layout<'a>) -> Script<'a>
Creates a new bound script for the specified layout context. The script must belong to the associated layout table.